package cn.ibizlab.businesscentral.core.rest;

import java.sql.Timestamp;
import java.util.ArrayList;
import java.util.List;
import java.util.Map;
import java.math.BigInteger;
import java.util.HashMap;
import lombok.extern.slf4j.Slf4j;
import com.alibaba.fastjson.JSONObject;
import javax.servlet.ServletRequest;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.cglib.beans.BeanCopier;
import org.springframework.http.ResponseEntity;
import org.springframework.web.bind.annotation.*;
import org.springframework.http.HttpStatus;
import org.springframework.data.domain.PageRequest;
import org.springframework.data.domain.Page;
import org.springframework.data.domain.PageImpl;
import org.springframework.data.domain.Pageable;
import org.springframework.util.StringUtils;
import org.springframework.context.annotation.Lazy;
import org.springframework.security.access.prepost.PreAuthorize;
import org.springframework.security.access.prepost.PostAuthorize;
import org.springframework.validation.annotation.Validated;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import io.swagger.annotations.ApiResponse;
import io.swagger.annotations.ApiResponses;
import cn.ibizlab.businesscentral.core.dto.*;
import cn.ibizlab.businesscentral.core.mapping.*;
import cn.ibizlab.businesscentral.core.odoo_product.domain.Product_product;
import cn.ibizlab.businesscentral.core.odoo_product.service.IProduct_productService;
import cn.ibizlab.businesscentral.core.odoo_product.filter.Product_productSearchContext;
import cn.ibizlab.businesscentral.util.annotation.VersionCheck;

@Slf4j
@Api(tags = {"产品" })
@RestController("Core-product_product")
@RequestMapping("")
public class Product_productResource {

    @Autowired
    public IProduct_productService product_productService;

    @Autowired
    @Lazy
    public Product_productMapping product_productMapping;

    @ApiOperation(value = "新建产品", tags = {"产品" },  notes = "新建产品")
	@RequestMapping(method = RequestMethod.POST, value = "/product_products")
    public ResponseEntity<Product_productDTO> create(@Validated @RequestBody Product_productDTO product_productdto) {
        Product_product domain = product_productMapping.toDomain(product_productdto);
		product_productService.create(domain);
        Product_productDTO dto = product_productMapping.toDto(domain);
		return ResponseEntity.status(HttpStatus.OK).body(dto);
    }

    @ApiOperation(value = "批量新建产品", tags = {"产品" },  notes = "批量新建产品")
	@RequestMapping(method = RequestMethod.POST, value = "/product_products/batch")
    public ResponseEntity<Boolean> createBatch(@RequestBody List<Product_productDTO> product_productdtos) {
        product_productService.createBatch(product_productMapping.toDomain(product_productdtos));
        return  ResponseEntity.status(HttpStatus.OK).body(true);
    }

    @VersionCheck(entity = "product_product" , versionfield = "writeDate")
    @ApiOperation(value = "更新产品", tags = {"产品" },  notes = "更新产品")
	@RequestMapping(method = RequestMethod.PUT, value = "/product_products/{product_product_id}")
    public ResponseEntity<Product_productDTO> update(@PathVariable("product_product_id") Long product_product_id, @RequestBody Product_productDTO product_productdto) {
		Product_product domain  = product_productMapping.toDomain(product_productdto);
        domain .setId(product_product_id);
		product_productService.update(domain );
		Product_productDTO dto = product_productMapping.toDto(domain );
        return ResponseEntity.status(HttpStatus.OK).body(dto);
    }

    @ApiOperation(value = "批量更新产品", tags = {"产品" },  notes = "批量更新产品")
	@RequestMapping(method = RequestMethod.PUT, value = "/product_products/batch")
    public ResponseEntity<Boolean> updateBatch(@RequestBody List<Product_productDTO> product_productdtos) {
        product_productService.updateBatch(product_productMapping.toDomain(product_productdtos));
        return  ResponseEntity.status(HttpStatus.OK).body(true);
    }

    @ApiOperation(value = "删除产品", tags = {"产品" },  notes = "删除产品")
	@RequestMapping(method = RequestMethod.DELETE, value = "/product_products/{product_product_id}")
    public ResponseEntity<Boolean> remove(@PathVariable("product_product_id") Long product_product_id) {
         return ResponseEntity.status(HttpStatus.OK).body(product_productService.remove(product_product_id));
    }

    @ApiOperation(value = "批量删除产品", tags = {"产品" },  notes = "批量删除产品")
	@RequestMapping(method = RequestMethod.DELETE, value = "/product_products/batch")
    public ResponseEntity<Boolean> removeBatch(@RequestBody List<Long> ids) {
        product_productService.removeBatch(ids);
        return  ResponseEntity.status(HttpStatus.OK).body(true);
    }

    @ApiOperation(value = "获取产品", tags = {"产品" },  notes = "获取产品")
	@RequestMapping(method = RequestMethod.GET, value = "/product_products/{product_product_id}")
    public ResponseEntity<Product_productDTO> get(@PathVariable("product_product_id") Long product_product_id) {
        Product_product domain = product_productService.get(product_product_id);
        Product_productDTO dto = product_productMapping.toDto(domain);
        return ResponseEntity.status(HttpStatus.OK).body(dto);
    }

	@ApiOperation(value = "获取默认查询", tags = {"产品" } ,notes = "获取默认查询")
    @RequestMapping(method= RequestMethod.GET , value="/product_products/fetchdefault")
	public ResponseEntity<List<Product_productDTO>> fetchDefault(Product_productSearchContext context) {
        Page<Product_product> domains = product_productService.searchDefault(context) ;
        List<Product_productDTO> list = product_productMapping.toDto(domains.getContent());
        return ResponseEntity.status(HttpStatus.OK)
                .header("x-page", String.valueOf(context.getPageable().getPageNumber()))
                .header("x-per-page", String.valueOf(context.getPageable().getPageSize()))
                .header("x-total", String.valueOf(domains.getTotalElements()))
                .body(list);
	}

	@ApiOperation(value = "查询默认查询", tags = {"产品" } ,notes = "查询默认查询")
    @RequestMapping(method= RequestMethod.POST , value="/product_products/searchdefault")
	public ResponseEntity<Page<Product_productDTO>> searchDefault(@RequestBody Product_productSearchContext context) {
        Page<Product_product> domains = product_productService.searchDefault(context) ;
	    return ResponseEntity.status(HttpStatus.OK)
                .body(new PageImpl(product_productMapping.toDto(domains.getContent()), context.getPageable(), domains.getTotalElements()));
	}


}

