package cn.ibizlab.businesscentral.core.rest;

import java.sql.Timestamp;
import java.util.ArrayList;
import java.util.List;
import java.util.Map;
import java.math.BigInteger;
import java.util.HashMap;
import lombok.extern.slf4j.Slf4j;
import com.alibaba.fastjson.JSONObject;
import javax.servlet.ServletRequest;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.cglib.beans.BeanCopier;
import org.springframework.http.ResponseEntity;
import org.springframework.web.bind.annotation.*;
import org.springframework.http.HttpStatus;
import org.springframework.data.domain.PageRequest;
import org.springframework.data.domain.Page;
import org.springframework.data.domain.PageImpl;
import org.springframework.data.domain.Pageable;
import org.springframework.util.StringUtils;
import org.springframework.context.annotation.Lazy;
import org.springframework.security.access.prepost.PreAuthorize;
import org.springframework.security.access.prepost.PostAuthorize;
import org.springframework.validation.annotation.Validated;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import io.swagger.annotations.ApiResponse;
import io.swagger.annotations.ApiResponses;
import cn.ibizlab.businesscentral.core.dto.*;
import cn.ibizlab.businesscentral.core.mapping.*;
import cn.ibizlab.businesscentral.core.odoo_product.domain.Product_supplierinfo;
import cn.ibizlab.businesscentral.core.odoo_product.service.IProduct_supplierinfoService;
import cn.ibizlab.businesscentral.core.odoo_product.filter.Product_supplierinfoSearchContext;
import cn.ibizlab.businesscentral.util.annotation.VersionCheck;

@Slf4j
@Api(tags = {"供应商价格表" })
@RestController("Core-product_supplierinfo")
@RequestMapping("")
public class Product_supplierinfoResource {

    @Autowired
    public IProduct_supplierinfoService product_supplierinfoService;

    @Autowired
    @Lazy
    public Product_supplierinfoMapping product_supplierinfoMapping;

    @ApiOperation(value = "新建供应商价格表", tags = {"供应商价格表" },  notes = "新建供应商价格表")
	@RequestMapping(method = RequestMethod.POST, value = "/product_supplierinfos")
    public ResponseEntity<Product_supplierinfoDTO> create(@Validated @RequestBody Product_supplierinfoDTO product_supplierinfodto) {
        Product_supplierinfo domain = product_supplierinfoMapping.toDomain(product_supplierinfodto);
		product_supplierinfoService.create(domain);
        Product_supplierinfoDTO dto = product_supplierinfoMapping.toDto(domain);
		return ResponseEntity.status(HttpStatus.OK).body(dto);
    }

    @ApiOperation(value = "批量新建供应商价格表", tags = {"供应商价格表" },  notes = "批量新建供应商价格表")
	@RequestMapping(method = RequestMethod.POST, value = "/product_supplierinfos/batch")
    public ResponseEntity<Boolean> createBatch(@RequestBody List<Product_supplierinfoDTO> product_supplierinfodtos) {
        product_supplierinfoService.createBatch(product_supplierinfoMapping.toDomain(product_supplierinfodtos));
        return  ResponseEntity.status(HttpStatus.OK).body(true);
    }

    @VersionCheck(entity = "product_supplierinfo" , versionfield = "writeDate")
    @ApiOperation(value = "更新供应商价格表", tags = {"供应商价格表" },  notes = "更新供应商价格表")
	@RequestMapping(method = RequestMethod.PUT, value = "/product_supplierinfos/{product_supplierinfo_id}")
    public ResponseEntity<Product_supplierinfoDTO> update(@PathVariable("product_supplierinfo_id") Long product_supplierinfo_id, @RequestBody Product_supplierinfoDTO product_supplierinfodto) {
		Product_supplierinfo domain  = product_supplierinfoMapping.toDomain(product_supplierinfodto);
        domain .setId(product_supplierinfo_id);
		product_supplierinfoService.update(domain );
		Product_supplierinfoDTO dto = product_supplierinfoMapping.toDto(domain );
        return ResponseEntity.status(HttpStatus.OK).body(dto);
    }

    @ApiOperation(value = "批量更新供应商价格表", tags = {"供应商价格表" },  notes = "批量更新供应商价格表")
	@RequestMapping(method = RequestMethod.PUT, value = "/product_supplierinfos/batch")
    public ResponseEntity<Boolean> updateBatch(@RequestBody List<Product_supplierinfoDTO> product_supplierinfodtos) {
        product_supplierinfoService.updateBatch(product_supplierinfoMapping.toDomain(product_supplierinfodtos));
        return  ResponseEntity.status(HttpStatus.OK).body(true);
    }

    @ApiOperation(value = "删除供应商价格表", tags = {"供应商价格表" },  notes = "删除供应商价格表")
	@RequestMapping(method = RequestMethod.DELETE, value = "/product_supplierinfos/{product_supplierinfo_id}")
    public ResponseEntity<Boolean> remove(@PathVariable("product_supplierinfo_id") Long product_supplierinfo_id) {
         return ResponseEntity.status(HttpStatus.OK).body(product_supplierinfoService.remove(product_supplierinfo_id));
    }

    @ApiOperation(value = "批量删除供应商价格表", tags = {"供应商价格表" },  notes = "批量删除供应商价格表")
	@RequestMapping(method = RequestMethod.DELETE, value = "/product_supplierinfos/batch")
    public ResponseEntity<Boolean> removeBatch(@RequestBody List<Long> ids) {
        product_supplierinfoService.removeBatch(ids);
        return  ResponseEntity.status(HttpStatus.OK).body(true);
    }

    @ApiOperation(value = "获取供应商价格表", tags = {"供应商价格表" },  notes = "获取供应商价格表")
	@RequestMapping(method = RequestMethod.GET, value = "/product_supplierinfos/{product_supplierinfo_id}")
    public ResponseEntity<Product_supplierinfoDTO> get(@PathVariable("product_supplierinfo_id") Long product_supplierinfo_id) {
        Product_supplierinfo domain = product_supplierinfoService.get(product_supplierinfo_id);
        Product_supplierinfoDTO dto = product_supplierinfoMapping.toDto(domain);
        return ResponseEntity.status(HttpStatus.OK).body(dto);
    }

	@ApiOperation(value = "获取默认查询", tags = {"供应商价格表" } ,notes = "获取默认查询")
    @RequestMapping(method= RequestMethod.GET , value="/product_supplierinfos/fetchdefault")
	public ResponseEntity<List<Product_supplierinfoDTO>> fetchDefault(Product_supplierinfoSearchContext context) {
        Page<Product_supplierinfo> domains = product_supplierinfoService.searchDefault(context) ;
        List<Product_supplierinfoDTO> list = product_supplierinfoMapping.toDto(domains.getContent());
        return ResponseEntity.status(HttpStatus.OK)
                .header("x-page", String.valueOf(context.getPageable().getPageNumber()))
                .header("x-per-page", String.valueOf(context.getPageable().getPageSize()))
                .header("x-total", String.valueOf(domains.getTotalElements()))
                .body(list);
	}

	@ApiOperation(value = "查询默认查询", tags = {"供应商价格表" } ,notes = "查询默认查询")
    @RequestMapping(method= RequestMethod.POST , value="/product_supplierinfos/searchdefault")
	public ResponseEntity<Page<Product_supplierinfoDTO>> searchDefault(@RequestBody Product_supplierinfoSearchContext context) {
        Page<Product_supplierinfo> domains = product_supplierinfoService.searchDefault(context) ;
	    return ResponseEntity.status(HttpStatus.OK)
                .body(new PageImpl(product_supplierinfoMapping.toDto(domains.getContent()), context.getPageable(), domains.getTotalElements()));
	}


}

